// Copyright 2018-2021 the Deno authors. All rights reserved. MIT license.

export enum MediaType {
  JavaScript = "JavaScript",
  Mjs = "Mjs",
  Cjs = "Cjs",
  Jsx = "Jsx",
  TypeScript = "TypeScript",
  Mts = "Mts",
  Cts = "Cts",
  Dts = "Dts",
  Dmts = "Dmts",
  Dcts = "Dcts",
  Tsx = "Tsx",
  Json = "Json",
  Wasm = "Wasm",
  TsBuildInfo = "TsBuildInfo",
  SourceMap = "SourceMap",
  Unknown = "Unknown",
}
